@@ -1,7 +1,5 @@
 import pprint
-import uuid
 import warnings
-import webbrowser
 from pathlib import Path
 
 import click
@@ -9,7 +7,7 @@ from halo import Halo  # type: ignore
 from humanfriendly import format_size, parse_size  # type: ignore
 from timeago import format as timeago_format  # type: ignore
 
-from treebeard.conf import signup_endpoint, treebeard_env, treebeard_web_url
+from treebeard.conf import signup_endpoint, treebeard_env
 from treebeard.helper import create_example_yaml, set_credentials
 from treebeard.util import fatal_exit
 from treebeard.version import get_version
@@ -26,19 +24,11 @@ warnings.filterwarnings(
 
 
 @click.command()
-@click.option("--email", prompt="Your email:")
-@click.option("--api_key", default=str(uuid.uuid4()))
+@click.option("--email")
+@click.option("--api_key")
 def configure(email: str, api_key: str):
     """Register with Treebeard services"""
-    project_id = set_credentials(email, api_key, signup_endpoint)
-    web_signup_url = f"{treebeard_web_url}/cli_signup?email={email}&api_key={api_key}&project_id={project_id}"
-    webbrowser.open_new_tab(web_signup_url)
-    click.echo(
-        click.style(
-            f"Please ensure you complete web signup at {web_signup_url} before continuing!",
-            fg="red",
-        )
-    )
+    set_credentials(email, api_key, signup_endpoint)
 
 
 @click.command()
